@@ -758,7 +758,8 @@ private:
     TCLAP::ValueArg<unsigned> max_padding{
         "",
         "max-padding",
-        "Maximum number of padding to add to all files in order to obfuscate their sizes. Each "
+        "Maximum number of padding (the unit is byte) to add to all files in order to obfuscate "
+        "their sizes. Each "
         "file has a different padding. Enabling this has a large performance cost.",
         false,
         0,
@@ -1027,6 +1028,11 @@ private:
                                       false,
                                       30,
                                       "int"};
+    TCLAP::SwitchArg skip_dot_dot{"",
+                                  "skip-dot-dot",
+                                  "When enabled, securefs will not return . and .. in `readdir` "
+                                  "calls. You should normally not need this.",
+                                  false};
 
 private:
     std::vector<const char*> to_c_style_args(const std::vector<std::string>& args)
@@ -1087,6 +1093,7 @@ public:
         cmdline.add(&fssubtype);
         cmdline.add(&noflock);
         cmdline.add(&attr_timeout);
+        cmdline.add(&skip_dot_dot);
         cmdline.parse(argc, argv);
 
         get_password(false);
@@ -1134,12 +1141,6 @@ public:
 
 #ifdef WIN32
         bool network_mount = is_network_mount(mount_point.getValue());
-        if (!network_mount && !is_drive_mount(mount_point.getValue()))
-        {
-            WARN_LOG("The mount point on Windows should be a drive path, such as Z:, or a network "
-                     "mount like \\\\securefs\\abcde. Otherwise some "
-                     "programs will get confused due to case sensitivity");
-        }
 #else
         try
         {
@@ -1327,6 +1328,10 @@ public:
             INFO_LOG("Mounting as a Unicode normalized filesystem");
             fsopt.flags.value() |= kOptionNFCFileName;
         }
+        if (skip_dot_dot.getValue())
+        {
+            fsopt.flags.value() |= kOptionSkipDotDot;
+        }
 
         if (config.version < 4)
         {
@@ -1592,6 +1597,8 @@ public:
         printf("Per file key generation algorithm: %s\n",
                format_version < 4 ? "HMAC-SHA256" : "AES");
         printf("Content cipher: %s\n", format_version < 4 ? "AES-256-GCM" : "AES-128-GCM");
+        printf("Maximum padding to obfuscate file sizes: %u byte(s)\n",
+               config_json.get("max_padding", 0u).asUInt());
         return 0;
     }
 };
