@@ -221,12 +221,10 @@ namespace lite
 
             while (traverser->next(&name, &stbuf))
             {
-#ifndef _WIN32
-                if (name == "." || name == "..")
+                if (fs->skip_dot_dot() && (name == "." || name == ".."))
                 {
                     continue;
                 }
-#endif
                 int rc =
                     // When random padding is enabled, we cannot obtain accurate size information
                     fs->has_padding() && (stbuf.st_mode & S_IFMT) == S_IFREG
@@ -352,9 +350,21 @@ namespace lite
     {
         auto func = [=]()
         {
-            auto filesystem = get_local_filesystem();
-            filesystem->mkdir(path, mode);
-            return 0;
+            try
+            {
+                auto filesystem = get_local_filesystem();
+                filesystem->mkdir(path, mode);
+                return 0;
+            }
+            catch (const ExceptionBase& e)
+            {
+                if (e.error_number() == EEXIST)
+                {
+                    // This occurs frequently and is not worth logging.
+                    return -EEXIST;
+                }
+                throw;
+            }
         };
         return FuseTracer::traced_call(func, FULL_FUNCTION_NAME, __LINE__, {{path}, {&mode}});
     }
